@@ -9,7 +9,7 @@
 #
 package Config::Model::Tester;
 # ABSTRACT: Test framework for Config::Model
-$Config::Model::Tester::VERSION = '2.059';
+$Config::Model::Tester::VERSION = '2.060';
 use warnings;
 use strict;
 use locale;
@@ -312,6 +312,22 @@ sub write_data_back {
     ok( 1, "$app_to_test write back done" );
 }
 
+sub check_file_mode {
+    my ($wr_dir, $t) = @_;
+
+    if (my $fm = $t->{file_mode}) {
+        foreach my $f (keys %$fm) {
+            my $expected_mode = $fm->{$f} ;
+            my $stat = $wr_dir->child($f)->stat;
+            ok($stat ,"stat found file $f");
+            if ($stat) {
+                my $mode = $stat->mode & 07777 ;
+                is($mode, $expected_mode, sprintf("check $f mode (got %o vs %o)",$mode,$expected_mode));
+            }
+        }
+    }
+}
+
 sub check_file_content {
     my ($wr_dir, $t) = @_;
 
@@ -488,6 +504,8 @@ sub run_model_test {
 
         check_file_content($wr_dir,$t) ;
 
+        check_file_mode($wr_dir,$t) ;
+
         check_added_or_removed_files ($conf_dir, $wr_dir, $t, @file_list) if $ex_data->is_dir;
 
         my $i2_root = create_second_instance ($app_to_test, $t_name, $wr_dir, $wr_dir2,$t, $config_dir_override);
@@ -586,7 +604,7 @@ Config::Model::Tester - Test framework for Config::Model
 
 =head1 VERSION
 
-version 2.059
+version 2.060
 
 =head1 SYNOPSIS
 
@@ -1001,6 +1019,18 @@ in an array ref:
 
 =item *
 
+Check the mode of the written files:
+
+  file_mode => {
+     "~/.ssh/ssh_config"     => 0600, # octal mode
+     "debian/stuff.postinst" => 0755,
+  }
+
+Only the last four octets of the mode are tested. I.e. the test is done with
+C< $file_mode & 07777 >
+
+=item *
+
 Check added or removed configuration files. If you expect changes,
 specify a subref to alter the file list:
 
